@@ -18,8 +18,9 @@ extern daddr	DFree;	/* pointer to end of tmp file */
 
 extern int	Jr_Len;		/* length of Just Read Line */
 
-extern long	io_chars;
-extern int	io_lines;
+extern long
+		io_chars,
+		io_lines;
 
 extern int	MakeTemp proto((char *, const char *));
 
@@ -69,7 +70,8 @@ extern void
 	WtModBuf proto((void)),
 	WrtReg proto((void)),
 	prCWD proto((void)),
-	prDIRS proto((void));
+	prDIRS proto((void)),
+	backup_name proto((const char *fname, const char *btype, char *bfname, size_t bfnamesize));
 
 /* Variables: */
 
