@@ -5,11 +5,15 @@
  * this notice is included in all the source files and documentation.     *
  **************************************************************************/
 
-
 /* (C) 1986, 1987, 1988 Ken Mitchum.  This code is intended only for use with Jove. */
 
-/* In 1995 December, D. Hugh Redelmeier hacked on the code to make
- * it work again.  The environment was Think C 5.0 under System 7.1.
+/* This code is not needed for MacOS X onwards, i.e any modern Mac,
+ * on which Jove's classic UNIX/POSIX code works well, as of 4.17.
+ * All #ifdef MAC is will be removed in a future version of Jove,
+ * unless someone volunteers to test it.
+ *
+ * This code was last tested since 1995 December, when D. Hugh Redelmeier
+ * hacked on the code to make it work on Think C 5.0 under System 7.1.
  *
  * Obligatory excuses:
  * - Hugh is not a Mac expert
@@ -495,11 +499,11 @@ int	fd;
 	return 0;
 }
 
-private SSIZE_T con_read proto((char *buf, size_t size));
+private JSSIZE_T con_read proto((char *buf, size_t size));
 
 /* Raw UNIX-like read */
 
-SSIZE_T
+JSSIZE_T
 read(fd, ubuf, n)
 int	fd;
 UnivPtr	ubuf;
@@ -532,7 +536,7 @@ size_t	n;
 
 /* Raw UNIX-like write */
 
-SSIZE_T
+JSSIZE_T
 write(fd, ubuf, n)
 int	fd;
 UnivConstPtr	ubuf;
@@ -646,7 +650,7 @@ const char *name;
 
 private ZXchar rawgetc proto((void));
 
-private SSIZE_T
+private JSSIZE_T
 con_read(buf, size)
 char *buf;
 size_t size;
